package com.miaxis.app.controller.common;

import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.question.domain.QuestionColumn;
import com.miaxis.question.domain.QuestionInfoKtNew;
import com.miaxis.question.dto.QuestionInfoFreeDTO;
import com.miaxis.question.dto.QuestionInfoNewDTO;
import com.miaxis.question.dto.QuestionInfoNewTestDTO;
import com.miaxis.question.service.IQuestionColumnService;
import com.miaxis.question.service.IQuestionInfoKtNewService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 【题库】Controller
 *
 * @author miaxis
 * @date 2021-10-20
 */
@RestController
@RequestMapping(Constants.OPEN_PREFIX+"/question2/info")
@Api(tags={"【通用-新题库】"})
public class CommonQuestionInfoNewController extends BaseController{


    @Autowired
    private IQuestionInfoKtNewService questionInfoKtNewService;

    @Autowired
    private IQuestionColumnService questionColumnService;

    /**
     * 查询模拟考试科目1与4题库
     */
    @GetMapping("/selectTestK14QuestionInfoList")
    @ApiOperation("取模拟考试题库")
    public ResponsePageInfo<QuestionInfoKtNew> selectTestK14QuestionInfoList(@ModelAttribute QuestionInfoNewTestDTO questionInfoNewTestDTO){
        List<QuestionInfoKtNew> list = questionInfoKtNewService.selectTestK14QuestionInfoList(questionInfoNewTestDTO);
        return toResponsePageInfo(list);
    }

    /**
     * 查询模拟考试科目1与4题库
     */
    @GetMapping("/selectTestK14QuestionInfoListnN")
    @ApiOperation("取模拟考试题库-无分页")
    public Response<List<QuestionInfoKtNew>> selectTestK14QuestionInfoListN(@ModelAttribute QuestionInfoNewTestDTO questionInfoNewTestDTO){
        List<QuestionInfoKtNew> list = questionInfoKtNewService.selectTestK14QuestionInfoList(questionInfoNewTestDTO);
        return Response.success(list);
    }

    /**
     * 查询免费题库
     */
    @GetMapping("/selectFreeQuestionInfo")
    @ApiOperation("查询免费题库")
    public ResponsePageInfo<QuestionInfoKtNew> selectFreeQuestionInfo(@ModelAttribute QuestionInfoFreeDTO freeDTO){
        List<QuestionInfoKtNew> list = questionInfoKtNewService.selectFreeQuestionInfo(freeDTO);
        return toResponsePageInfo(list);
    }

    @GetMapping(value = "/getQuestionColumn")
    @ApiOperation("获取题库分类")
    public Response<List<QuestionColumn>> getQuestionColumn(@ModelAttribute QuestionColumn questionColumn){
        List<QuestionColumn> list = questionColumnService.selectQuestionColumnList(questionColumn);
        return Response.success(list);
    }


    /**
     * 查询题库列表
     */
    @GetMapping("/list")
    @ApiOperation("查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfoKtNew> list(@ModelAttribute QuestionInfoNewDTO questionInfoNewDTO){
        startPage();
        List<QuestionInfoKtNew> list = questionInfoKtNewService.selectQuestionInfoList(questionInfoNewDTO);
        return toResponsePageInfo(list);
    }



    /**
     * 获取题库详细信息多个题库
     */
    @GetMapping(value = "/getQuestionInfoByIds")
    @ApiOperation("获取题库详细信息批量取题")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids",value = "题目ids" ,dataType = "List", required = true)})
    public ResponsePageInfo<QuestionInfoKtNew> getQuestionInfoByIds(Long[] ids){
        List<QuestionInfoKtNew> list = questionInfoKtNewService.selectQuestionInfoListByIds(ids);
        return toResponsePageInfo(list);
    }

}

