package com.miaxis.pc.controller.question;

import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.question.domain.QuestionInfo;
import com.miaxis.question.dto.*;
import com.miaxis.question.service.IQuestionInfoService;
import com.miaxis.question.vo.*;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【题库】Controller
 *
 * @author miaxis
 * @date 2021-12-24
 */
@RestController
@RequestMapping("pc/question/info")
@Api(tags={"【PC-题库】"})
public class PcQuestionInfoController extends BaseController{
    @Autowired
    private IQuestionInfoService questionInfoService;

    /**
     * 后台-查询题库列表
     */
    @GetMapping("/list")
    @ApiOperation("后台-查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfoExcelVo> list(@ModelAttribute QuestionInfoSortDTO questionInfoSortDTO){
        startPage();
        initParams(questionInfoSortDTO);
        List<QuestionInfoExcelVo> list = questionInfoService.selectQuestionInfoSortList(questionInfoSortDTO);
        return toResponsePageInfo(list);
    }

    private void initParams(QuestionInfoSortDTO questionInfoSortDTO) {
        Integer issueTypeValue = questionInfoSortDTO.getIssueTypeValue();
        switch (issueTypeValue){
            case 1:
                questionInfoSortDTO.setIssueTypeParmName("class_issue");
                questionInfoSortDTO.setSortName("class_sort");
                break;
            case 2:
                questionInfoSortDTO.setIssueTypeParmName("excell_issue");
                questionInfoSortDTO.setSortName("excell_sort");
                break;
            case 3:
                questionInfoSortDTO.setIssueTypeParmName("place_issue");
                questionInfoSortDTO.setSortName("place_sort");
                break;
            case 4:
                questionInfoSortDTO.setIssueTypeParmName("seque_issue");
                questionInfoSortDTO.setSortName("seque_sort");
                break;
        }

    }

    /**
     * 取题查询题库列表
     */
    @GetMapping("/qlist")
    @ApiOperation("取题查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfo> qlist(@ModelAttribute QuestionInfoDTO questionInfoDTO){
        startPage();
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfoDTO);
        return toResponsePageInfo(list);
    }



    /**
     * 根据专题类型获取具体分类
     */
    @GetMapping(value = "/issueType")
    @ApiOperation("根据专题类型获取具体分类")
    public Response<List<QuestionInfoExcelTypeVo>> getTypes(Integer subject,Integer issueTypeValue)
    {

        return Response.success(questionInfoService.getIssueTypes(issueTypeValue,subject));
    }


    /**
     * 修改题库
     */
    @Log(title = "题库", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改顺序")
    public Response questionInfoSortUpate(@RequestBody QuestionInfoSortUpateDTO questionInfoSortUpateDTO){
        initParams(questionInfoSortUpateDTO);
        questionInfoService.updateSortById(questionInfoSortUpateDTO);
        return Response.success();
    }

    private void initParams(QuestionInfoSortUpateDTO dto) {
        Integer issueTypeValue = dto.getIssueTypeValue();
        switch (issueTypeValue){
            case 1:
                dto.setSortName("class_sort");
                break;
            case 2:
                dto.setSortName("excell_sort");
                break;
            case 3:
                dto.setSortName("place_sort");
                break;
            case 4:
                dto.setSortName("seque_sort");
                break;
        }
    }




    /**
     * 查询题库列表

    @GetMapping("/list")
    @ApiOperation("查询题库列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<QuestionInfo> list(@ModelAttribute QuestionInfoDTO questionInfoDTO){
        startPage();
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoList(questionInfoDTO);
        return toResponsePageInfo(list);
    }
     */


    /**
     * 获取题库详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("获取题库详细信息")
    public Response<QuestionInfo> getInfo(
            @ApiParam(name = "id", value = "题库参数", required = true)
            @PathVariable("id") Long id
    ){
        return Response.success(questionInfoService.getById(id));
    }

    /**
     * 获取题库详细信息多个题库
     */
    @GetMapping(value = "/getQuestionInfoByIds")
    @ApiOperation("获取题库详细信息批量取题")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids",value = "题目ids" ,dataType = "List", required = true)})
    public ResponsePageInfo<QuestionInfo> getQuestionInfoByIds(Long[] ids){
        List<QuestionInfo> list = questionInfoService.selectQuestionInfoListByIds(ids);
        return toResponsePageInfo(list);
    }



    /**
     * 获取精选分类
     */
    @GetMapping(value = "/selectJxQuestionInfo")
    @ApiOperation("获取精选题分类")
    public Response<List<QuestionInfoJxVO>> selectJxQuestionInfo(@ModelAttribute QuestionInfoFlDTO questionInfoFlDTO) {
        return Response.success(questionInfoService.selectJxQuestionInfo(questionInfoFlDTO));
    }


    /**
     * 获取地方分类
     */
    @GetMapping(value = "/selectDfQuestionInfo")
    @ApiOperation("获取地方题分类")
    public Response<List<QuestionInfoDfVO>> selectDfQuestionInfo(@ModelAttribute QuestionInfoFlDTO questionInfoFlDTO) {
        return Response.success(questionInfoService.selectDfQuestionInfo(questionInfoFlDTO));
    }

    /**
     * 获取分类专题分类
     */
    @GetMapping(value = "/selectFlQuestionInfo")
    @ApiOperation("获取分类专题分类")
    public Response<List<QuestionInfoFlVO>> selectFlQuestionInfo(@ModelAttribute QuestionInfoFlDTO questionInfoFlDTO) {
        return Response.success(questionInfoService.selectFlQuestionInfo(questionInfoFlDTO));
    }

    /**
     * 获取顺序练习分类
     */
    @GetMapping(value = "/selectSxQuestionInfo")
    @ApiOperation("获取顺序练习分类")
    public Response<List<QuestionInfoSxVO>> selectSxQuestionInfo(@ModelAttribute QuestionInfoFlDTO questionInfoFlDTO) {


        return Response.success(questionInfoService.selectSxQuestionInfo(questionInfoFlDTO));
    }




    /**
     * 查询模拟考试科目1与4题库
     */
    @GetMapping("/selectTestK14QuestionInfoList")
    @ApiOperation("取模拟考试题库")
    public ResponsePageInfo<QuestionInfo> selectTestK14QuestionInfoList(@ModelAttribute QuestionInfoTestDTO questionInfoTestDTO){
        List<QuestionInfo> list = questionInfoService.selectTestK14QuestionInfoList(questionInfoTestDTO);
        return toResponsePageInfo(list);
    }


    /**
     * 查询秘密卷
     */
    @GetMapping("/selectMiQuestionInfoList")
    @ApiOperation("查询秘密卷")
    public ResponsePageInfo<QuestionInfo> selectMiQuestionInfoList(@ModelAttribute QuestionInfoMiDTO questionInfoMiDTO){
        List<QuestionInfo> list = questionInfoService.selectMiQuestionInfoList(questionInfoMiDTO);
        return toResponsePageInfo(list);
    }



}
